-
Notifications
You must be signed in to change notification settings - Fork 576
ThreadNetwork macOS xcode27.0 b5
Alex Soto edited this page Aug 10, 2026
·
1 revision
#ThreadNetwork.framework
diff -ruN /Applications/Xcode_27.0.0-beta4.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h /Applications/Xcode_27.0.0-beta5.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h
--- /Applications/Xcode_27.0.0-beta4.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h 2026-07-11 01:50:02
+++ /Applications/Xcode_27.0.0-beta5.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h 2026-08-03 23:43:30
@@ -79,6 +79,31 @@
/// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.
- (void)retrieveAllActiveCredentials:(void (^)(NSSet<THCredentials*>* _Nullable credentials, NSError* _Nullable error))completion API_AVAILABLE(ios(16.4)) NS_SWIFT_ASYNC_NAME(allActiveCredentials());
+/// Requests all active Thread credentials with active border routers around from the framework.
+///
+/// When calling this method, you will receive credentials for active border routers around.
+/// You receive all credentials agnostic to team ID.
+/// Unlike ``retrieveAllActiveCredentials:``, this method returns active credentials
+/// on the device regardless of who actually stored it.
+///
+/// - Parameters:
+/// - completion: The completion handler the framework calls when the
+/// credentials become available.
+///
+/// - Note: This method asks for user permission to share available credentials.
+/// If user denies the permission then the completion will contain error with code 15.
+///
+/// > Concurrency Note: You can call this method from synchronous code using a completion handler,
+/// > as shown on this page, or you can call it as an asynchronous method that has the
+/// > following declaration:
+/// >
+/// > ```swift
+/// > var activeCredentialsForNearbyNetworks: Set<THCredentials> { get async throws }
+/// > ```
+/// >
+/// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.
+- (void)retrieveActiveCredentialsForNearbyNetworksWithCompletion:(void (^)(NSSet<THCredentials*>* _Nullable credentials, NSError* _Nullable error))completion API_AVAILABLE(ios(27.0)) NS_SWIFT_ASYNC_NAME(getter:activeCredentialsForNearbyNetworks());
+
/// Deletes Thread network credentials from the framework database for a Border
/// Agent.
///
@@ -236,14 +261,12 @@
///
/// This method scans for Thread credential sharing capable Apple Border Routers, selects an eligible device, and requests to generate an ephemeral 9-digit code and start credential sharing mode.
///
-/// When you call this method, an alert appears asking for user permission to
-/// access credentials. The one-time admin code is displayed internally via an alert;
-/// it is not returned to the caller.
+/// When you call this method, the ephemeral 9-digit code appears on screen along with a warning message; it is not returned to the caller.
///
-////// - Parameters:
+/// - Parameters:
/// - extendedPANID: The extended PAN identifier of the Thread network.
-/// - completion: The completion handler the framework calls after the user
-/// acknowledges the alert. The `error` parameter is nil on success, or
+/// - completion: The completion handler the framework calls once credential
+/// sharing mode has started. The `error` parameter is nil on success, or
/// non-nil if credential sharing mode could not be enabled.
///
/// > Concurrency Note: You can call this method from synchronous code using a completion handler,
@@ -252,13 +275,13 @@
/// >
/// > ```swift
/// > // Completion handler form:
/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data, completion: @escaping (Error?) -> Void)
/// >
/// > // Async form (throws on failure):
/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data) async throws
/// > ```
/// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.
-- (void)enableCredentialSharingModeWithExtendedPANId:(nonnull NSData*)xpanId completion:(void (^)(NSError * _Nullable error))completion API_AVAILABLE(ios(27.0)) NS_SWIFT_ASYNC_NAME(enableCredentialSharingModeWithExtendedPANId(extendedPANId:));
+- (void)enableCredentialSharingModeForExtendedPANID:(nonnull NSData*)extendedPANID completion:(void (^)(NSError * _Nullable error))completion API_AVAILABLE(ios(27.0)) NS_SWIFT_ASYNC_NAME(enableCredentialSharingMode(forExtendedPANID:));
@end
NS_ASSUME_NONNULL_END
@@ -252,13 +275,13 @@
/// > ```swift
/// > // Completion handler form:
-/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data, completion: @escaping (Error?) -> Void)
+/// > func enableCredentialSharingMode(forExtendedPANID extendedPANID: Data, completion: @escaping (Error?) -> Void)
/// >
/// > // Async form (throws on failure):
@@ -252,13 +275,13 @@
/// >
/// > // Async form (throws on failure):
-/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data) async throws
+/// > func enableCredentialSharingMode(forExtendedPANID extendedPANID: Data) async throws
/// > ```
/// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.